@@ -81,26 +81,12 @@ def materialize(
             src_stream_position_np.item(),
         )
         dl_digest = delta_locator.digest()
-        max_retry = 5
-        retry_count =0
-        while True:
-            if retry_count >= max_retry:
-                raise RuntimeError(
-                    "max get_delta_manifest retries exceeded in materialize")
-            try:
-                manifest = manifest_cache.setdefault(
-                    dl_digest,
-                    deltacat_storage.get_delta_manifest(delta_locator),
-                )
-                if retry_count > 0:
-                    logger.info(f"get_delta_manifest retry {retry_count} succeeded!")
-                break
-            except Exception as e:
-                logger.info(f"get_delta_manifest in limit_input_deltas failed "
-                            f"{retry_count} times: {e}")
-                time.sleep(0.5)
-                retry_count += 1
-                pass
+
+        manifest = manifest_cache.setdefault(
+            dl_digest,
+            deltacat_storage.get_delta_manifest(delta_locator),
+        )
+
         read_kwargs_provider = None
         # for delimited text output, disable type inference to prevent
         # unintentional type-casting side-effects and improve performance
